@@ -2,18 +2,22 @@ from .utils import (
     safely_get_value_from_key,
     save_object_to_file,
     safely_pop_value_from_key,
-    get_auth_header
+    search_key,
+    get_auth_header,
+    CLIENT_VERSION,
 )
 from .clean_items import (
     clean_content_text,
-    clean_backstage_attachement
+    clean_backstage_attachement,
 )
 
 __all__ = [
     "safely_get_value_from_key",
     "safely_pop_value_from_key",
     "save_object_to_file",
+    "search_key",
     "get_auth_header",
     "clean_content_text",
-    "clean_backstage_attachement"
+    "clean_backstage_attachement",
+    "CLIENT_VERSION",
 ]
